@@ -42,11 +42,11 @@ class CustomCommandExecutor(RemoteConnection, ReportingCommandExecutor):
             skip_reporting (bool): True if command should not be reported to Agent, False otherwise
 
         Returns:
-            response: Response returned by the Selenium remote webdriver server
+            response: Response returned by the Selenium remote WebDriver server
         """
         self.update_known_test_name()
 
-        self.step_helper.handle_timeout(self.settings.timeout, self.agent_client.agent_session.session_id)
+        self.step_helper.handle_timeout(self.settings.timeout)
 
         # Handling sleep before execution
         self.step_helper.handle_sleep(self.settings.sleep_timing_type, self.settings.sleep_time, command)
